@@ -22,15 +22,15 @@ CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-import os
-import subprocess
 import sys
 
+import debmake.sh
+
 
 ###########################################################################
 # yn: ask mes and execute command
 ###########################################################################
-def yn(mes, command, yes):
+def yn(mes, command, yes, exit_no=True):
     if yes == 1:
         yn = "y"
     elif yes == 2:
@@ -43,20 +43,21 @@ def yn(mes, command, yes):
             yn = yn[0].lower()
     if yn == "y":
         if command:
-            print("I: $ {}".format(command), file=sys.stderr)
-            if subprocess.call(command, shell=True) != 0:
-                print("E: failed to run command.", file=sys.stderr)
-                exit(1)
-    else:
-        print('E: terminating since "n" chosen at Y/n question.', file=sys.stderr)
+            debmake.sh.sh(command)
+    elif exit_no:
+        print(
+            'E: terminating as ERROR since "n" chosen at Y/n question.', file=sys.stderr
+        )
         exit(1)
+    else:
+        pass
     return
 
 
 if __name__ == "__main__":
-    print("I: ask", file=sys.stderr)
+    print("I: ask")
     yn("list current directory (ask)", "ls -la", 0)
-    print("I: always yes", file=sys.stderr)
+    print("I: always yes")
     yn("list current directory (always yes)", "ls -la", 1)
-    print("I: never yes", file=sys.stderr)
-    yn("list current directory (never yes)", "ls -la", 2)
+    print("I: never yes")
+    yn("list current directory (never yes)", "ls -la", 2, exit_no=False)
